use serde::{Deserialize, Serialize};


#[derive(Debug, PartialEq, Clone, Serialize, Deserialize, Default)]
pub struct Tile {
    pub name: String,
    pub description: Option<String>,
    pub symbol: String,
    pub color: String,
}

impl Tile {
    pub fn new(name: &str, sym: &str, col: &str) -> Self {
        Self {
            name: name.to_string(),
            description: None,
            symbol: sym.to_string(),
            color: col.to_string(),
        }
    }
    pub fn with_description(name: &str, sym: &str, col: &str, desc: &str) -> Self {
        Self {
            name: name.to_string(),
            description: Some(desc.to_string()),
            symbol: sym.to_string(),
            color: col.to_string(),
        }
    }
    pub fn is_empty(&self) -> bool {
        if self.described() {
            return false;
        }
        self.name.is_empty() && self.symbol.is_empty() && self.color.is_empty()
    }
    pub fn described(&self) -> bool {
        if let Some(desc) = &self.description {
            return !desc.is_empty()
        }
        false
    }
}
